/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of libosso-abook
 *
 * Copyright (C) 2008-2009 Nokia Corporation. All rights reserved.
 *
 * Contact: Joergen Scheibengruber <jorgen.scheibengruber@nokia.com>
 */

#ifndef __OSSO_ABOOK_SETTINGS_H__
#define __OSSO_ABOOK_SETTINGS_H__

#include <gconf/gconf-client.h>

G_BEGIN_DECLS

#define OSSO_ABOOK_SETTINGS_KEY_CONTACT_ORDER \
        "/apps/osso-addressbook/contact-order"
#define OSSO_ABOOK_SETTINGS_KEY_HOME_APPLETS \
        "/apps/osso-addressbook/home-applets"
#define OSSO_ABOOK_SETTINGS_KEY_LAST_IMSI \
        "/apps/osso-addressbook/last-imsi"
#define OSSO_ABOOK_SETTINGS_KEY_NAME_ORDER \
        "/apps/osso-addressbook/name-order"
#define OSSO_ABOOK_SETTINGS_KEY_SELF_CARD \
        "/apps/osso-addressbook/self-vcard"
#define OSSO_ABOOK_SETTINGS_KEY_SELF_AVATAR_IMPORTED \
        "/apps/osso-addressbook/self-avatar-imported"
#define OSSO_ABOOK_SETTINGS_KEY_VOICEMAIL_VCARD \
        "/apps/osso-addressbook/voicemail-vcard"

/* dropped feature */
#ifdef OSSO_ABOOK_HAVE_SPEED_DIAL
#define OSSO_ABOOK_SETTINGS_KEY_SPEED_DIAL_DIR \
        "/apps/osso-addressbook/speed-dial"                     /*< no-schema >*/
#define OSSO_ABOOK_SETTINGS_KEY_VOICEMAIL_INDEX \
        "/apps/osso-addressbook/vmbx-index"                     /*< no-schema >*/
#endif /* OSSO_ABOOK_HAVE_SPEED_DIAL */

/**
 * OssoABookContactOrder:
 * @OSSO_ABOOK_CONTACT_ORDER_NONE: Don't sort at all.
 * @OSSO_ABOOK_CONTACT_ORDER_NAME: Sort by (display) name.
 * @OSSO_ABOOK_CONTACT_ORDER_PRESENCE: Sort by presence, then name.
 * @OSSO_ABOOK_CONTACT_ORDER_CUSTOM: Use custom #OssoABookListStoreCompareFunc for sorting.
 *
 * The sorting modes of a #OssoABookListStore.
 */
typedef enum {
        OSSO_ABOOK_CONTACT_ORDER_NONE = -1,
        OSSO_ABOOK_CONTACT_ORDER_NAME,     /* Sort by name */
        OSSO_ABOOK_CONTACT_ORDER_PRESENCE, /* Sort by presence, then name */
        OSSO_ABOOK_CONTACT_ORDER_CUSTOM,
} OssoABookContactOrder;

/**
 * OssoABookNameOrder:
 * @OSSO_ABOOK_NAME_ORDER_FIRST:      Display given name first
 * @OSSO_ABOOK_NAME_ORDER_LAST:       Display family name first, separated by comma
 * @OSSO_ABOOK_NAME_ORDER_LAST_SPACE: Display family name first, separated by space
 * @OSSO_ABOOK_NAME_ORDER_NICK:       Display nickname only
 *
 * Preferred order for name components for sorting and display.
 */
typedef enum {
        OSSO_ABOOK_NAME_ORDER_FIRST,
        OSSO_ABOOK_NAME_ORDER_LAST,
        OSSO_ABOOK_NAME_ORDER_LAST_SPACE,
        OSSO_ABOOK_NAME_ORDER_NICK,
} OssoABookNameOrder;

GConfClient *
osso_abook_get_gconf_client                   (void);


OssoABookContactOrder
osso_abook_settings_get_contact_order         (void);

GSList *
osso_abook_settings_get_home_applets          (void);

OssoABookNameOrder
osso_abook_settings_get_name_order            (void);

gboolean
osso_abook_settings_get_self_avatar_imported  (void);

const char *
osso_abook_settings_get_picture_folder        (void);

gboolean
osso_abook_settings_set_contact_order         (OssoABookContactOrder order);

gboolean
osso_abook_settings_set_home_applets          (GSList               *list);

gboolean
osso_abook_settings_set_name_order            (OssoABookNameOrder    order);

gboolean
osso_abook_settings_set_self_avatar_imported  (gboolean              imported);

#ifdef OSSO_ABOOK_HAVE_SPEED_DIAL

int
osso_abook_settings_get_voicemail_index       (void);

gboolean
osso_abook_settings_set_voicemail_index       (int                   index);

#endif /* OSSO_ABOOK_HAVE_SPEED_DIAL */

G_END_DECLS

#endif /* __OSSO_ABOOK_SETTINGS_H__ */
